#
# spec file for package baresip
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover   20
%global libname lib%{name}%{sover}
Name:           baresip
Version:        3.21.0
Release:        1.1
Summary:        Modular SIP useragent
License:        BSD-3-Clause
Group:          Productivity/Telephony/SIP/Clients
URL:            https://github.com/baresip/baresip
Source:         %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  ilbc-devel
BuildRequires:  jack-devel
BuildRequires:  pkgconfig
BuildRequires:  sndio-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(aom)
BuildRequires:  pkgconfig(codec2)
BuildRequires:  pkgconfig(fdk-aac)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-net-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcrypto) >= 1.1.1
BuildRequires:  pkgconfig(libmosquitto)
BuildRequires:  pkgconfig(libmp3lame)
BuildRequires:  pkgconfig(libmpg123)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libre) >= 2.10.0
BuildRequires:  pkgconfig(librem) >= 2.10.0
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(spandsp)
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(twolame)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(webrtc-audio-processing)
Recommends:     baresip-devel
Recommends:     baresip-video

%description
A modular SIP user-agent
with support for audio and video, and many IETF standards
such as SIP, SDP, RTP/RTCP, STUN, TURN, and ICE.

Supports both IPv4 and IPv6, and the following features.
 * Audio codecs: AMR, G.711, G.722, G.726, GSM, L16, MPA, OPUS.
 * Video codecs: H.263, H.264, H.265, MPEG4, VP8, VP9.
 * Audio drivers: Alsa, JACK, OSS, Portaudio, sndio.
 * Video sources: FFmpeg avformat, Video4Linux2, X11 Grabber.
 * Video output: SDL2, X11, DirectFB.
 * NAT Traversal: STUN, TURN, ICE, NATBD, NAT-PMP, PCP.
 * Media encryption: SRTP, DTLS-SRTP.
 * DNS Service Discovery: Avahi.
 * Telemetry messaging: MQTT.
 * Control interfaces: JSON-over-TCP.

%package        video
Summary:        Video support for the Baresip useragent
Group:          Productivity/Telephony/SIP/Clients
Requires:       %{name} = %{version}

%description   video
A modular SIP user-agent
with support for audio and video, and many IETF standards
such as SIP, SDP, RTP/RTCP, STUN, TURN, and ICE.

Supports both IPv4 and IPv6, and the following features.
 * Audio codecs: AMR, G.711, G.722, G.726, GSM, L16, MPA, OPUS.
 * Video codecs: H.263, H.264, H.265, MPEG4, VP8, VP9.
 * Audio drivers: Alsa, JACK, OSS, Portaudio, sndio.
 * Video sources: FFmpeg avformat, Video4Linux2, X11 Grabber.
 * Video output: SDL2, X11, DirectFB.
 * NAT Traversal: STUN, TURN, ICE, NATBD, NAT-PMP, PCP.
 * Media encryption: SRTP, DTLS-SRTP.
 * DNS Service Discovery: Avahi.
 * Telemetry messaging: MQTT.
 * Control interfaces: JSON-over-TCP.

This subpackage provides the modules that are needed for video
support.

%package devel
Summary:        Development files for the baresip library
Requires:       %{libname} = %{version}-%{release}
Requires:       pkgconfig

%description devel
The baresip-devel package includes header files and libraries necessary
for developing programs which use the baresip C library.

%package -n %{libname}
Summary:        Standard library for baresip
Provides:       %{name} = %{version}-%{release}
Obsoletes:      %{name} < %{version}-%{release}

%description -n %{libname}
This package contains the shared library needed to run programs compiled with
baresip

%prep
%autosetup -p1
mv modules/mqtt/README.md README.mqtt
sed 's|%{_prefix}/local/lib|%{_libdir}/|g' -i src/config.c
sed 's|%{_prefix}/local/lib|%{_libdir}/|g' -i docs/examples/config
sed 's|%{_prefix}/local/share|%{_datadir}/|g' -i docs/examples/config

%build
%cmake \
	-DCMAKE_SKIP_BUILD_RPATH:BOOL=ON
%cmake_build

%install
%cmake_install

%check
%ctest

%ldconfig_scriptlets -n %{libname}

%files
%license LICENSE
%doc CHANGELOG.md README.md README.mqtt
%doc docs/examples
%{_bindir}/baresip
%{_datadir}/baresip
%{_datadir}/applications/com.github.baresip.desktop
%dir %{_libdir}/baresip
%dir %{_libdir}/baresip/modules
%{_libdir}/baresip/modules/aac.so
%{_libdir}/baresip/modules/account.so
%{_libdir}/baresip/modules/alsa.so
%{_libdir}/baresip/modules/aubridge.so
%{_libdir}/baresip/modules/auconv.so
%{_libdir}/baresip/modules/aufile.so
%{_libdir}/baresip/modules/augain.so
%{_libdir}/baresip/modules/auresamp.so
%{_libdir}/baresip/modules/ausine.so
%{_libdir}/baresip/modules/codec2.so
%{_libdir}/baresip/modules/cons.so
%{_libdir}/baresip/modules/contact.so
%{_libdir}/baresip/modules/ctrl_dbus.so
%{_libdir}/baresip/modules/ctrl_tcp.so
%{_libdir}/baresip/modules/debug_cmd.so
%{_libdir}/baresip/modules/dtls_srtp.so
%{_libdir}/baresip/modules/ebuacip.so
%{_libdir}/baresip/modules/echo.so
%{_libdir}/baresip/modules/evdev.so
%{_libdir}/baresip/modules/g711.so
%{_libdir}/baresip/modules/g722.so
%{_libdir}/baresip/modules/g726.so
%{_libdir}/baresip/modules/gtk.so
%{_libdir}/baresip/modules/httpd.so
%{_libdir}/baresip/modules/httpreq.so
%{_libdir}/baresip/modules/ice.so
%{_libdir}/baresip/modules/in_band_dtmf.so
%{_libdir}/baresip/modules/jack.so
%{_libdir}/baresip/modules/l16.so
%{_libdir}/baresip/modules/menu.so
%{_libdir}/baresip/modules/mixausrc.so
%{_libdir}/baresip/modules/mixminus.so
%{_libdir}/baresip/modules/mpa.so
%{_libdir}/baresip/modules/mqtt.so
%{_libdir}/baresip/modules/mwi.so
%{_libdir}/baresip/modules/natpmp.so
%{_libdir}/baresip/modules/netroam.so
%{_libdir}/baresip/modules/opus.so
%{_libdir}/baresip/modules/opus_multistream.so
%{_libdir}/baresip/modules/pcp.so
%{_libdir}/baresip/modules/plc.so
%{_libdir}/baresip/modules/presence.so
%{_libdir}/baresip/modules/portaudio.so
%{_libdir}/baresip/modules/pulse.so
%{_libdir}/baresip/modules/rtcpsummary.so
%{_libdir}/baresip/modules/serreg.so
%{_libdir}/baresip/modules/snapshot.so
%{_libdir}/baresip/modules/sndfile.so
%{_libdir}/baresip/modules/srtp.so
%{_libdir}/baresip/modules/stdio.so
%{_libdir}/baresip/modules/stun.so
%{_libdir}/baresip/modules/syslog.so
%{_libdir}/baresip/modules/turn.so
%{_libdir}/baresip/modules/uuid.so
%{_libdir}/baresip/modules/vumeter.so
%{_libdir}/baresip/modules/webrtc_aec.so

%files devel
%license LICENSE
%{_libdir}/lib%{name}.so
%{_includedir}/%{name}.h
%{_libdir}/pkgconfig/lib%{name}.pc

%files -n %{libname}
%license LICENSE
%{_libdir}/libbaresip.so.%{sover}*

%files video
%license LICENSE
%{_libdir}/baresip/modules/av1.so
%{_libdir}/baresip/modules/avfilter.so
%{_libdir}/baresip/modules/avcodec.so
%{_libdir}/baresip/modules/avformat.so
%{_libdir}/baresip/modules/fakevideo.so
%{_libdir}/baresip/modules/gst.so
%{_libdir}/baresip/modules/sdl.so
%{_libdir}/baresip/modules/selfview.so
%{_libdir}/baresip/modules/swscale.so
%{_libdir}/baresip/modules/vidbridge.so
%{_libdir}/baresip/modules/vidinfo.so
%{_libdir}/baresip/modules/vp8.so
%{_libdir}/baresip/modules/vp9.so
%{_libdir}/baresip/modules/x11.so

%changelog
* Wed Apr 16 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 3.21.0:
  * GTK added standalone main window
  * wasapi: Add WASAPI Audio module
  * add contact commands
  * many bug fixes and functionality improvements
- fixes build, and build with cmake 4 (boo#1239788)
* Fri Oct 25 2024 Pedro Monreal <pmonreal@suse.com>
- Do not hardcode the openssl version [bsc#1219879]
  * Replace libopenssl-1_1-devel with libopenssl-devel
  * Fix in_band_dtmf.so lib directory for x86
* Thu Oct  3 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.16.0
  * https://github.com/baresip/baresip/releases/tag/v3.16.0
  * https://github.com/baresip/baresip/releases/tag/v3.15.0
  * https://github.com/baresip/baresip/releases/tag/v3.14.0
  * https://github.com/baresip/baresip/releases/tag/v3.13.0
  * https://github.com/baresip/baresip/releases/tag/v3.12.0
* Sun Apr 14 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.11.0
  * https://github.com/baresip/baresip/releases/tag/v3.11.0
  * https://github.com/baresip/baresip/releases/tag/v3.10.1
  * https://github.com/baresip/baresip/releases/tag/v3.10.0
  * https://github.com/baresip/baresip/releases/tag/v3.9.0
* Wed Jan  3 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.8.1
  * aur: set audio format correctly.
  * cmake: add only non-system link paths to rpath.
* Wed Dec 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 3.8.0
  Changes:
  * https://github.com/baresip/baresip/releases/tag/v3.8.0
  * https://github.com/baresip/baresip/releases/tag/v3.7.0
  * https://github.com/baresip/baresip/releases/tag/v3.5.1
  * https://github.com/baresip/baresip/releases/tag/v3.5.0
  * https://github.com/baresip/baresip/releases/tag/v3.4.0
  * https://github.com/baresip/baresip/releases/tag/v3.3.0
  * https://github.com/baresip/baresip/releases/tag/v3.2.0
  * https://github.com/baresip/baresip/releases/tag/v3.1.0
  * https://github.com/baresip/baresip/releases/tag/v3.0.0
  * https://github.com/baresip/baresip/releases/tag/v2.12.0
  * https://github.com/baresip/baresip/releases/tag/v2.11.0
* Thu Jan  5 2023 Matthias Eliasson <elimat@opensuse.org>
- Update to release 2.10.0
  * sdl: small improvements
  * vidinfo: allow all pixel formats
  * vid: add support for YUV422P pixel format
  * avformat: fix hwaccel vaapi
  * mk: add deprecate notice
  * mingw: upgrade to OpenSSL 3.0.7
  * dshow: fix some warnings
  * dshow: fix pragma warning
  * ci: install libsdl2 development package
  * sdl: work in progress fixes for multi-threading
  * Stop segfaulting when no URI is passed to dial command
  * ice: local candidate policy config
  * auresamp: check handler arguments
  * fixes 2315 and GTK errors on quit
  * auresamp: avoid division
  * cmake: check for XShm.h
  * pulse_async: avoid integer overrun for timestamps in recorder
  * ua: use sdp connection data instead origin
  * rtpext: move from baresip to re
  * acc,stream: add rtcp_mux account param
  * video: video_update cleanup
  * aufile/src: add auframe support
  * ice/tmr_async_handler: fix possible segfault
  * webrtc: fix browser offer handling
  * Space at the beginning of sip: creates errors
  * opus_multistream: update mimetype to ad-hoc standard
  * webrtc: add offerer and recvonly options
  * test: replace RSA cert with EC cert
  * Add OPTIONS handling for webrtc demo
  * mk: remove rtpext.c from srcs.mk
  * ua: change refer log to info()
- switch to Cmake builds
- add devel and libbaresip2 sub-packages
- add pcp module
- remove sndio and v4l2 modules
* Thu Aug 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.0
  * Removed deprecated modules: gsm, gst, gst_video
  * Added modules: pulse_async
* Tue Jun 28 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 2.4.0:
  * No high level changelog provided, see packaged CHANGELOG.md for
    details.
- Changes from version 2.3.0, 2.0.2, 2.0.1, 2.0.0:
  * No high level changelog provided, see packaged CHANGELOG.md for
    details.
- Add build dependencies on:
  * aom: Enables module av1.
  * fdk-aac: Enables module aac.
  * gcc-c++, webrtc-audio-processing: Enables module webrtc_aec.
  * gstreamer-app-1.0: Enables module gst_video.
  * libmp3lame, libmpg123, twolame: Enables module mpa.
  * libmosquitto: Enables module mqtt.
  * portaudio: Enables module portaudio.
  * sndio: Enables module sndio.
- Drop build dependency on cairo: Module cairo has been removed.
- Enable extra module avfilter.
* Wed May 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.1.0
  * Added DTMF tones for A B C D
  * Fix interaction between CLI menu and GTK menu
  * gtk: show call_peername in notify title
  * call: when video stream is disabled, stop also video display
  * dtls_srtp: use tls_set_selfsigned_rsa with keysize 2048
  * avcodec: fix H.264 interop with Firefox
  * ice: fix segfault in connh
  * aac: handle missing bitrate parameter in SDP format
  * menu: fix segfault in /aubitrate command
  * ice: remove support for ICE-lite
  * opengles: remove module
  * A lot other bug fixes and enhancements
* Mon Jun 29 2020 Jan Engelhardt <jengelh@inai.de>
- Avoid sentences in title lines.
* Wed Jun 24 2020 Martin Hauke <mardnh@gmx.de>
- Specfile overhaul
* Fri Nov  5 2010 Alfred E. Heggestad <aeh@db.org>
- Initial build.
